@@ -1,4 +1,4 @@
-# Copyright (c) 2014-2019 Cedric Bellegarde <cedric.bellegarde@adishatz.org>
+# Copyright (c) 2014-2020 Cedric Bellegarde <cedric.bellegarde@adishatz.org>
 # Copyright (c) 2019 Jordi Romera <jordiromera@users.sourceforge.net>
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -225,7 +225,9 @@ class CollectionScanner(GObject.GObject, TagReader):
         # are playing with a compilation or an album
         self.__new_non_album_artists += list(
             set(added_artist_ids) - set(added_album_artist_ids))
-        if storage_type & StorageType.COLLECTION:
+        if storage_type & (StorageType.COLLECTION |
+                           StorageType.SPOTIFY_NEW_RELEASES |
+                           StorageType.SPOTIFY_SIMILARS):
             for artist_id in added_album_artist_ids:
                 if artist_id in self.__new_non_album_artists:
                     self.__new_non_album_artists.remove(artist_id)
@@ -647,7 +649,7 @@ class CollectionScanner(GObject.GObject, TagReader):
         (year, timestamp) = self.get_original_year(tags)
         if year is None:
             (year, timestamp) = self.get_year(tags)
-        duration = int(info.get_duration() / 1000000000)
+        duration = int(info.get_duration() / 1000000)
 
         if version != "":
             title += " (%s)" % version
