@@ -1,4 +1,4 @@
-# Copyright (c) 2014-2019 Cedric Bellegarde <cedric.bellegarde@adishatz.org>
+# Copyright (c) 2014-2020 Cedric Bellegarde <cedric.bellegarde@adishatz.org>
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
@@ -185,38 +185,6 @@ class ViewsContainer:
             view.grab_focus()
         return view
 
-    def get_view_album_ids(self, genre_ids, artist_ids):
-        """
-            Get albums view for genres/artists
-            @param genre_ids as [int]
-            @param artist_ids as [int]
-            @return [int]
-        """
-        items = []
-        if genre_ids and genre_ids[0] == Type.POPULARS:
-            items = App().albums.get_rated()
-            count = 100 - len(items)
-            for album in App().albums.get_populars(count):
-                if album not in items:
-                    items.append(album)
-        elif genre_ids and genre_ids[0] == Type.LOVED:
-            items = App().albums.get_loved_albums()
-        elif genre_ids and genre_ids[0] == Type.RECENTS:
-            items = App().albums.get_recents()
-        elif genre_ids and genre_ids[0] == Type.LITTLE:
-            items = App().albums.get_little_played()
-        elif genre_ids and genre_ids[0] == Type.RANDOMS:
-            items = App().albums.get_randoms()
-        elif genre_ids and genre_ids[0] == Type.COMPILATIONS:
-            items = App().albums.get_compilation_ids([])
-        elif genre_ids and not artist_ids:
-            if App().settings.get_value("show-compilations-in-album-view"):
-                items = App().albums.get_compilation_ids(genre_ids)
-            items += App().albums.get_ids([], genre_ids)
-        else:
-            items = App().albums.get_ids(artist_ids, genre_ids)
-        return items
-
 ##############
 # PROTECTED  #
 ##############
