@@ -40,19 +40,18 @@ class BinPlayer:
         self._current_playback_track = Track()
         self._next_track = Track()
         self._prev_track = Track()
-        self._crossfading = False
-        self._playbin = self.__playbin1 = Gst.ElementFactory.make(
+        self._playbin = self._playbin1 = Gst.ElementFactory.make(
             "playbin", "player")
-        self.__playbin2 = Gst.ElementFactory.make("playbin", "player")
-        self._plugins = self._plugins1 = PluginsPlayer(self.__playbin1)
-        self._plugins2 = PluginsPlayer(self.__playbin2)
-        self._playbin.connect("notify::volume", self.__on_volume_changed)
-        for playbin in [self.__playbin1, self.__playbin2]:
+        self._playbin2 = Gst.ElementFactory.make("playbin", "player")
+        self._plugins = self._plugins1 = PluginsPlayer(self._playbin1)
+        self._plugins2 = PluginsPlayer(self._playbin2)
+        for playbin in [self._playbin1, self._playbin2]:
             flags = playbin.get_property("flags")
             flags &= ~GstPlayFlags.GST_PLAY_FLAG_VIDEO
             playbin.set_property("flags", flags)
             playbin.set_property("buffer-size", 5 << 20)
             playbin.set_property("buffer-duration", 10 * Gst.SECOND)
+            playbin.connect("notify::volume", self.__on_volume_changed)
             playbin.connect("about-to-finish",
                             self._on_stream_about_to_finish)
             bus = playbin.get_bus()
@@ -64,32 +63,14 @@ class BinPlayer:
             bus.connect("message::tag", self._on_bus_message_tag)
         self._start_time = 0
 
-    def get_status(self):
-        """
-            Playback status
-            @return Gstreamer state
-        """
-        ok, state, pending = self._playbin.get_state(Gst.CLOCK_TIME_NONE)
-        if ok == Gst.StateChangeReturn.ASYNC:
-            state = pending
-        elif (ok != Gst.StateChangeReturn.SUCCESS):
-            state = Gst.State.NULL
-        return state
-
     def load(self, track):
         """
-            Stop current track, load track id and play it
+            Load track and play it
             @param track as Track
         """
-        if self._crossfading and\
-           self._current_track.id is not None and\
-           self.is_playing and\
-           not isinstance(track, Radio):
-            duration = App().settings.get_value(
-                "transition-duration").get_int32()
-            self.__do_crossfade(duration, track)
-        else:
-            self.__load(track)
+        self._playbin.set_state(Gst.State.NULL)
+        if self._load_track(track):
+            self.play()
 
     def play(self):
         """
@@ -109,33 +90,32 @@ class BinPlayer:
         """
         if isinstance(App().player.current_track, Radio):
             self._playbin.set_state(Gst.State.NULL)
+            emit_signal(self, "status-changed")
         else:
             self._playbin.set_state(Gst.State.PAUSED)
-        emit_signal(self, "status-changed")
+            emit_signal(self, "status-changed")
 
-    def stop(self, force=False):
+    def stop(self):
         """
             Change player state to STOPPED
             @param force as bool
         """
         self._current_track = Track()
+        self._prev_track = Track()
+        self._next_track = Track()
+        emit_signal(self, "current-changed")
+        emit_signal(self, "prev-changed")
+        emit_signal(self, "next-changed")
         self._playbin.set_state(Gst.State.NULL)
         emit_signal(self, "status-changed")
-        emit_signal(self, "current-changed")
-        if force:
-            self._prev_track = Track()
-            self._next_track = Track()
-            emit_signal(self, "prev-changed")
-            emit_signal(self, "next-changed")
-            self.clear_albums()
 
     def stop_all(self):
         """
             Stop all bins, lollypop should quit now
         """
         # Stop
-        self.__playbin1.set_state(Gst.State.NULL)
-        self.__playbin2.set_state(Gst.State.NULL)
+        self._playbin1.set_state(Gst.State.NULL)
+        self._playbin2.set_state(Gst.State.NULL)
 
     def play_pause(self):
         """
@@ -154,13 +134,13 @@ class BinPlayer:
         if self.current_track.id is None:
             return
         position = self.position
-        self.__load(self.current_track)
-        GLib.timeout_add(100, self.seek, position / Gst.SECOND)
+        self.load(self.current_track)
+        GLib.timeout_add(100, self.seek, position)
 
     def seek(self, position):
         """
             Seek current track to position
-            @param position as seconds
+            @param position as int (ms)
         """
         if self._current_track.id is None:
             return
@@ -172,9 +152,32 @@ class BinPlayer:
             self._playbin.seek_simple(Gst.Format.TIME,
                                       Gst.SeekFlags.FLUSH |
                                       Gst.SeekFlags.KEY_UNIT,
-                                      position * Gst.SECOND)
+                                      position * 1000000)
             emit_signal(self, "seeked", position)
 
+    def get_status(self):
+        """
+            Playback status
+            @return Gstreamer state
+        """
+        ok, state, pending = self._playbin.get_state(Gst.CLOCK_TIME_NONE)
+        if ok == Gst.StateChangeReturn.ASYNC:
+            state = pending
+        elif (ok != Gst.StateChangeReturn.SUCCESS):
+            state = Gst.State.NULL
+        return state
+
+    def set_volume(self, rate):
+        """
+            Set player volume rate
+            @param rate as double
+        """
+        if rate < 0.0:
+            rate = 0.0
+        elif rate > 1.0:
+            rate = 1.0
+        self._playbin.set_volume(GstAudio.StreamVolumeFormat.CUBIC, rate)
+
     @property
     def plugins(self):
         """
@@ -203,15 +206,19 @@ class BinPlayer:
             Return bin playback position
             @HACK handle crossefade here, as we know we're going to be
             called every seconds
-            @return position in Gst.SECOND
+            @return position as int (ms)
         """
-        position = self._playbin.query_position(Gst.Format.TIME)[1]
-        if self._crossfading and self._current_track.duration > 0:
-            duration = self._current_track.duration - position / Gst.SECOND
-            if duration < App().settings.get_value(
-                    "transition-duration").get_int32():
-                self.__do_crossfade(duration)
-        return position
+        return self.__get_bin_position(self._playbin)
+
+    @property
+    def remaining(self):
+        """
+            Return remaining duration
+            @return duration as int (ms)
+        """
+        position = self._playbin.query_position(Gst.Format.TIME)[1] / 1000000
+        duration = self._current_track.duration
+        return int(duration - position)
 
     @property
     def current_track(self):
@@ -228,36 +235,15 @@ class BinPlayer:
         """
         return self._playbin.get_volume(GstAudio.StreamVolumeFormat.CUBIC)
 
-    def set_volume(self, rate):
-        """
-            Set player volume rate
-            @param rate as double
-        """
-        if rate < 0.0:
-            rate = 0.0
-        elif rate > 1.0:
-            rate = 1.0
-        self.__playbin1.set_volume(GstAudio.StreamVolumeFormat.CUBIC, rate)
-        self.__playbin2.set_volume(GstAudio.StreamVolumeFormat.CUBIC, rate)
-
-    def next(self):
-        """
-            Go next track
-        """
-        pass
-
 #######################
 # PROTECTED           #
 #######################
-    def _load_track(self, track, init_volume=True):
+    def _load_track(self, track):
         """
             Load track
             @param track as Track
-            @param init volume as bool
             @return False if track not loaded
         """
-        if init_volume:
-            self._plugins.volume.props.volume = 1.0
         Logger.debug("BinPlayer::_load_track(): %s" % track.uri)
         try:
             self.__cancellable.cancel()
@@ -316,11 +302,11 @@ class BinPlayer:
         """
         played = time() - finished_start_time
         # Last.fm policy, force it for ListenBrainz too
-        if finished.duration < 30:
+        if finished.duration < 30000:
             return
         # We can listen if the track has been played
         # for at least half its duration, or for 4 minutes
-        if played >= finished.duration / 2 or played >= 240:
+        if played >= finished.duration / 2000 or played >= 240:
             for scrobbler in App().scrobblers:
                 if scrobbler.available:
                     scrobbler.listen(finished, int(finished_start_time))
@@ -396,7 +382,7 @@ class BinPlayer:
             go next otherwise
         """
         # Don't do anything if crossfade on, track already changed
-        if self._crossfading:
+        if self.crossfading:
             return
         if isinstance(App().player.current_track, Radio):
             return
@@ -404,8 +390,6 @@ class BinPlayer:
             if self._next_track.id is None:
                 # We are in gstreamer thread
                 GLib.idle_add(self.stop)
-                # Reenable as it has been disabled by do_crossfading()
-                self.update_crossfading()
             else:
                 self._load_track(self._next_track)
                 self.next()
@@ -418,7 +402,7 @@ class BinPlayer:
         try:
             Logger.debug("Player::__on_stream_about_to_finish(): %s" % playbin)
             # Don't do anything if crossfade on, track already changed
-            if self._crossfading:
+            if self.crossfading:
                 return
             if isinstance(App().player.current_track, Radio):
                 return
@@ -439,8 +423,6 @@ class BinPlayer:
             if self._next_track.id is None:
                 # We are in gstreamer thread
                 GLib.idle_add(self.stop)
-                # Reenable as it has been disabled by do_crossfading()
-                self.update_crossfading()
             else:
                 self._load_track(self._next_track)
         except Exception as e:
@@ -449,110 +431,13 @@ class BinPlayer:
 #######################
 # PRIVATE             #
 #######################
-    def __load(self, track, init_volume=True):
+    def __get_bin_position(self, playbin):
         """
-            Stop current track, load track id and play it
-            If was playing, do not use play as status doesn"t changed
-            @param track as Track
-            @param init volume as bool
-        """
-        was_playing = self.is_playing
-        self._playbin.set_state(Gst.State.NULL)
-        if self._load_track(track, init_volume):
-            if was_playing:
-                self._playbin.set_state(Gst.State.PLAYING)
-            else:
-                self.play()
-
-    def __volume_up(self, playbin, plugins, duration):
-        """
-            Make volume going up smoothly
+            Get position for playbin
             @param playbin as Gst.Bin
-            @param plugins as PluginsPlayer
-            @param duration as int
+            @return position as int (ms)
         """
-        # We are not the active playbin, stop all
-        if self._playbin != playbin:
-            return
-        if duration > 0:
-            vol = plugins.volume.props.volume
-            steps = duration / 0.25
-            vol_up = (1.0 - vol) / steps
-            rate = vol + vol_up
-            if rate < 1.0:
-                plugins.volume.props.volume = rate
-                GLib.timeout_add(250, self.__volume_up,
-                                 playbin, plugins, duration - 0.25)
-            else:
-                plugins.volume.props.volume = 1.0
-        else:
-            plugins.volume.props.volume = 1.0
-
-    def __volume_down(self, playbin, plugins, duration):
-        """
-            Make volume going down smoothly
-            @param playbin as Gst.Bin
-            @param plugins as PluginsPlayer
-            @param duration as int
-        """
-        # We are again the active playbin, stop all
-        if self._playbin == playbin:
-            return
-        if duration > 0:
-            vol = plugins.volume.props.volume
-            steps = duration / 0.25
-            vol_down = vol / steps
-            rate = vol - vol_down
-            if rate > 0:
-                plugins.volume.props.volume = rate
-                GLib.timeout_add(250, self.__volume_down,
-                                 playbin, plugins, duration - 0.25)
-            else:
-                plugins.volume.props.volume = 0.0
-                playbin.set_state(Gst.State.NULL)
-        else:
-            plugins.volume.props.volume = 0.0
-            playbin.set_state(Gst.State.NULL)
-
-    def __do_crossfade(self, duration, track=None):
-        """
-            Crossfade tracks
-            @param duration as int
-            @param track as Track
-        """
-        if track is None:
-            self._scrobble(self._current_track, self._start_time)
-            # Increment popularity
-            App().tracks.set_more_popular(self._current_track.id)
-            # In party mode, linear popularity
-            if self.is_party:
-                pop_to_add = 1
-            # In normal mode, based on tracks count
-            else:
-                count = self._current_track.album.tracks_count
-                pop_to_add = int(App().albums.max_count / count)
-            App().albums.set_more_popular(self._current_track.album_id,
-                                          pop_to_add)
-
-        GLib.idle_add(self.__volume_down, self._playbin,
-                      self._plugins, duration)
-        if self._playbin == self.__playbin2:
-            self._playbin = self.__playbin1
-            self._plugins = self._plugins1
-        else:
-            self._playbin = self.__playbin2
-            self._plugins = self._plugins2
-
-        if track is not None and track.id is not None:
-            self.__load(track, False)
-            self._plugins.volume.props.volume = 0
-            GLib.idle_add(self.__volume_up, self._playbin,
-                          self._plugins, duration)
-        elif self._next_track.id is not None:
-            self.__load(self._next_track, False)
-            self._plugins.volume.props.volume = 0
-            GLib.idle_add(self.__volume_up, self._playbin,
-                          self._plugins, duration)
+        return playbin.query_position(Gst.Format.TIME)[1] / 1000000
 
     def __update_current_duration(self, track, uri):
         """
@@ -562,7 +447,7 @@ class BinPlayer:
         """
         try:
             discoverer = Discoverer()
-            duration = discoverer.get_info(uri).get_duration() / 1000000000
+            duration = discoverer.get_info(uri).get_duration() / 1000000
             if duration != track.duration and duration > 0:
                 App().tracks.set_duration(track.id, int(duration))
                 track.reset("duration")
@@ -572,14 +457,9 @@ class BinPlayer:
 
     def __on_volume_changed(self, playbin, sink):
         """
-            Update volume
+            Emit volume-changed signal
             @param playbin as Gst.Bin
             @param sink as Gst.Sink
         """
-        if playbin == self.__playbin1:
-            vol = self.__playbin1.get_volume(GstAudio.StreamVolumeFormat.CUBIC)
-            self.__playbin2.set_volume(GstAudio.StreamVolumeFormat.CUBIC, vol)
-        else:
-            vol = self.__playbin2.get_volume(GstAudio.StreamVolumeFormat.CUBIC)
-            self.__playbin1.set_volume(GstAudio.StreamVolumeFormat.CUBIC, vol)
+        App().settings.set_value("volume-rate", GLib.Variant("d", self.volume))
         emit_signal(self, "volume-changed")
