@@ -1,4 +1,4 @@
-# Copyright (c) 2014-2019 Cedric Bellegarde <cedric.bellegarde@adishatz.org>
+# Copyright (c) 2014-2020 Cedric Bellegarde <cedric.bellegarde@adishatz.org>
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
@@ -37,9 +37,12 @@ class PlaylistsManagerView(FlowBoxView, SignalsHelper):
                              ViewType.SCROLLED | ViewType.OVERLAY)
         self.__signal_id = None
         self._empty_icon_name = "emblem-documents-symbolic"
-        self.__banner = PlaylistsBannerWidget(self)
-        self.__banner.show()
-        self.add_widget(self._box, self.__banner)
+        if self.args is None:
+            self.add_widget(self._box, None)
+        else:
+            self.__banner = PlaylistsBannerWidget(self)
+            self.__banner.show()
+            self.add_widget(self._box, self.__banner)
         return [
             (App().playlists, "playlists-changed", "_on_playlist_changed")
         ]
@@ -77,12 +80,34 @@ class PlaylistsManagerView(FlowBoxView, SignalsHelper):
         """
         if self.destroyed:
             return None
+        # Compatibility with SelectionList
+        if isinstance(value, tuple):
+            value = value[0]
         widget = PlaylistRoundedWidget(value, self._view_type,
                                        self.font_height)
         self._box.insert(widget, -1)
         widget.show()
         return widget
 
+    def _sort_func(self, widget1, widget2):
+        """
+            Sort function
+            @param widget1 as PlaylistRoundedWidget
+            @param widget2 as PlaylistRoundedWidget
+        """
+        # Static vs static
+        if widget1.data < 0 and widget2.data < 0:
+            return widget1.data < widget2.data
+        # Static entries always on top
+        elif widget2.data < 0:
+            return True
+        # Static entries always on top
+        if widget1.data < 0:
+            return False
+        # String comparaison for non static
+        else:
+            return strcoll(widget1.name, widget2.name)
+
     def _on_child_activated(self, flowbox, child):
         """
             Navigate into child
@@ -170,34 +195,14 @@ class PlaylistsManagerView(FlowBoxView, SignalsHelper):
         menu_widget = MenuBuilder(menu)
         if child.data >= 0:
             menu_widget = MenuBuilder(menu)
-            main = menu_widget.get_child_by_name("main")
             menu_ext = PlaylistMenuExt(child.data)
             menu_ext.show()
-            main.add(menu_ext)
+            menu_widget.append_widget(menu_ext)
         else:
             menu_widget = MenuBuilder(menu)
         menu_widget.show()
         popup_widget(menu_widget, child)
 
-    def __sort_func(self, widget1, widget2):
-        """
-            Sort function
-            @param widget1 as PlaylistRoundedWidget
-            @param widget2 as PlaylistRoundedWidget
-        """
-        # Static vs static
-        if widget1.data < 0 and widget2.data < 0:
-            return widget1.data < widget2.data
-        # Static entries always on top
-        elif widget2.data < 0:
-            return True
-        # Static entries always on top
-        if widget1.data < 0:
-            return False
-        # String comparaison for non static
-        else:
-            return strcoll(widget1.name, widget2.name)
-
 
 class PlaylistsManagerDeviceView(PlaylistsManagerView):
     """
@@ -212,7 +217,6 @@ class PlaylistsManagerDeviceView(PlaylistsManagerView):
         """
         PlaylistsManagerView.__init__(self, view_type)
         self.__index = index
-        self._new_button.hide()
 
     def populate(self):
         """
