@@ -1,4 +1,4 @@
-# Copyright (c) 2014-2019 Cedric Bellegarde <cedric.bellegarde@adishatz.org>
+# Copyright (c) 2014-2020 Cedric Bellegarde <cedric.bellegarde@adishatz.org>
 # Copyright (C) 2010 Jonathan Matthew (replay gain code)
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -118,7 +118,7 @@ class EqualizerWidget(Gtk.Bin):
         App().settings.set_value("equalizer-enabled",
                                  GLib.Variant("b", active))
         for plugin in App().player.plugins:
-            plugin.init()
+            plugin.build_audiofilter()
         App().player.reload_track()
         self.__combobox.set_sensitive(active)
         for i in range(0, 10):
